@@ -360,6 +360,48 @@ class Client(Singleton):
                 
         return False, '获取失败'
 
+    def get_cloud_url(self, path, url, force_copy=False, min_size=0, timeout=60, refresh=False):
+        if '://' in url:
+            bucket, bucket_name = url.split('://')[1].split('/')
+        else:
+            bucket, bucket_name = url.split('/')
+
+        task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
+        if not refresh:
+            if '://' in url:
+                return True, url
+            cached_resp = self.redis.get(task_id)
+
+            if cached_resp is not None and len(cached_resp) > 0:
+                resp = json.loads(cached_resp)
+                if resp['ret']:
+                    tmp_url = resp['url']
+                    return True, tmp_url
+        else:
+            self.redis.delkey(task_id)
+        ret = self.mq.publish(self.get_topic, {
+            'bucket': bucket,
+            'bucket_name': bucket_name,
+            'refresh': 'yes' if refresh else 'no'
+        })
+        if ret:
+            t = time.time()
+            resp = None
+            while True:
+                if time.time() - t >= timeout:
+                    break
+                
+                resp = self.redis.get(task_id)
+                if resp is not None and len(resp) > 0:
+                    resp = json.loads(resp)
+                    if resp['ret']:
+                        tmp_url = resp['url']
+                        return True, tmp_url
+                
+                time.sleep(1/30)
+                
+        return False, '获取失败'
+
     async def get_async(self, path, url, force_copy=False, min_size=0, timeout=60, refresh=False):
         if '://' in url:
             bucket, bucket_name = url.split('://')[1].split('/')
@@ -407,6 +449,51 @@ class Client(Singleton):
                     await asyncio.sleep(1/30)
         except Exception as e:
             return False, '获取失败'
+    
+    async def get_cloud_url_async(self, path, url, force_copy=False, min_size=0, timeout=60, refresh=False):
+        if '://' in url:
+            bucket, bucket_name = url.split('://')[1].split('/')
+        else:
+            bucket, bucket_name = url.split('/')
+            
+        task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
+        if not refresh:
+            if '://' in url:
+                return True, url
+
+            cached_resp = await self.redis.get(task_id)
+
+            if cached_resp is not None and len(cached_resp) > 0:
+                resp = json.loads(cached_resp)
+                if resp['ret']:
+                    tmp_url = resp['url']
+                    return True, tmp_url
+        else:
+            self.redis.delkey(task_id)
+        
+        try:
+            ret = await self.mq.async_publish(self.get_topic, {
+                'bucket': bucket,
+                'bucket_name': bucket_name,
+                'refresh': 'yes' if refresh else 'no'
+            })
+            if ret:
+                t = time.time()
+                resp = None
+                while True:
+                    if time.time() - t >= timeout:
+                        break
+                    
+                    resp = await self.redis.get(task_id)
+                    if resp is not None and len(resp) > 0:
+                        resp = json.loads(resp)
+                        if resp['ret']:
+                            tmp_url = resp['url']
+                            return True, tmp_url
+                    
+                    await asyncio.sleep(1/30)
+        except Exception as e:
+            return False, '获取失败'
 
     async def get_mq_conn(self):
         return await self.mq.get_mq_conn()
@@ -442,7 +529,7 @@ class Client(Singleton):
             return False, str(e)
         
     
-    async def put_async(self, path, bucket, bucket_name, timeout=10, file_ttl=-1):
+    async def put_async(self, path, bucket, bucket_name, timeout=60, file_ttl=-1):
         ret, e = await self.put_to_cloud_async(path, bucket, bucket_name)
         if ret:
             ret, e = await self.put_from_cloud_async(e, bucket, bucket_name, timeout, file_ttl)
